<?php

/**
 * Provide a public-facing view for the plugin
 *
 * This file is used to markup the public-facing aspects of the plugin.
 *
 * @link       https://loyaltymatters.co.uk
 * @since      1.0.0
 *
 * @package    Villas_365
 * @subpackage Villas_365/public/partials
 */

wp_enqueue_style('_villas-365-fontawesome', plugin_dir_url( __FILE__ ) . "../../assets/css/villas-365-fontawesome.css", [], "5.9.0");
wp_enqueue_style('_villas-365-fancybox-styles', plugin_dir_url( __FILE__ ) . "../../assets/libs/fancybox/fancybox.css", [], "3.5.7");
wp_enqueue_style('_villas-365-styles', plugin_dir_url( __FILE__ ) . "../../assets/css/villas-365-styles.css", ["_villas-365-fontawesome", "_villas-365-fancybox-styles"], "1.0");
wp_enqueue_style('_villas-365-property-styles', plugin_dir_url( __FILE__ ) . "../../assets/css/villas-365-property.css", ["_villas-365-styles"], "1.0");
wp_enqueue_script('_villas-365-bootstrap', plugin_dir_url( __FILE__ ) . "../../assets/libs/bootstrap.js", ["jquery"], "4.3.1", true);
wp_enqueue_script('_villas-365-scripts', plugin_dir_url( __FILE__ ) . '../../assets/js/villas-365-scripts.js', ['jquery', '_villas-365-bootstrap'], "1.0", true);
wp_enqueue_script('_villas-365-fancybox', plugin_dir_url( __FILE__ ) . "../../assets/js/villas-365-fancybox.js", ["jquery", "_villas-365-scripts"], "3.5.7", true);
wp_enqueue_script('_villas-365-property-banner', plugin_dir_url( __FILE__ ) . "../../assets/js/villas-365-property-banner.js", ["jquery", "_villas-365-scripts", "_villas-365-fancybox"], "1.0.0", true);

//Get the property details
$property = $property_atts["property"];
$gallery = null;
$gallerySingle = false;
if(!is_null($property))
{
	$gallery = API365::GetPropertyGallery($property->id);
}

$showIntroBox = true;
if(array_key_exists("showintrobox", $property_atts) &&
	!is_null($property_atts["showintrobox"]) &
	((!is_bool($property_atts["showintrobox"]) && $property_atts["showintrobox"] == "false") || (is_bool($property_atts["showintrobox"]) && !$property_atts["showintrobox"])))
{
	$showIntroBox = false;
}

$bookingPageUrl = get_home_url() . "/book-now";

if(!is_null($property)) :

	if(isset($property_atts) && (count($property_atts) > 0) && array_key_exists("bookingPageUrl", $property_atts) && !is_null($property_atts["bookingPageUrl"]) && ($property_atts["bookingPageUrl"] !== ""))
	{
		$bookingPageUrl = $property_atts["bookingPageUrl"];
	}

	$bookingPageUrl .= "?property=" . $property->id;

	if(!isset($villas365PropertiesFullHeightBannerClass) || is_null($villas365PropertiesFullHeightBannerClass))
	{
		$villas365PropertiesFullHeightBannerClass = Helpers365::GetPropertiesFullHeightBannerClass();
	}
?>
<div class="_villas-365-bootstrap _villas-365-property-container _villas-365-property-banner-container">
	<?php if(!is_null($gallery) && (count($gallery) > 1)) : ?>
	<div class="_banner">
		<div id="property-banner" class="banner-carousel hidden-print carousel slide" data-ride="carousel" data-interval="false<?php /*echo (defined('DEBUG_365') && DEBUG_365 ? 'false' : '10000');*/ ?>">
			<?php if(!$gallerySingle) : ?>
			<!-- Indicators -->
			<ol class="carousel-indicators d-none d-lg-flex">
				<?php foreach($gallery as $key => $banner) : ?>
				<li data-target="#property-banner" data-slide-to="<?php echo $key; ?>" class="<?php echo (($key == 0) ? 'active' : ''); ?>"></li>
				<?php endforeach; ?>
			</ol>
			<?php endif; ?>

			<!-- Wrapper for slides -->
			<div class="carousel-inner">
				<?php foreach($gallery as $key => $banner) : ?>
				<div class="carousel-item <?php echo (($key == 0) ? 'active' : ''); ?>">
					<div class="banner-item-container<?php echo $villas365PropertiesFullHeightBannerClass; ?>" style="background-image:url('<?php echo esc_html($banner->link_banner); ?>')" data-fancybox="_property-images-fancybox" data-src="<?php echo esc_html($banner->link_banner); ?>">
						<img src="<?php echo esc_html($banner->link_banner); ?>" alt="" class="img-fluid d-lg-none">
					</div>
				</div>
				<?php
				if($gallerySingle)
				{
					break;
				}
				?>
				<?php endforeach; ?>
			</div>

			<?php if(!$gallerySingle) : ?>
			<div class="left carousel-control carousel-control-prev" role="button" data-slide="prev" data-target="#property-banner">
				<i class="fas fa-chevron-left prev-icon carousel-control-icon" aria-hidden="true"></i>
				<span class="sr-only">Previous</span>
			</div>
			<div class="right carousel-control carousel-control-next" role="button" data-slide="next" data-target="#property-banner">
				<i class="fas fa-chevron-right next-icon carousel-control-icon" aria-hidden="true"></i>
				<span class="sr-only">Next</span>
			</div>
			<?php endif; ?>
		</div>

		<?php if($showIntroBox) : ?>
		<div class="_villas-365-property-header">
			<div class="container">
				<div class="row align-items-center">
					<div class="col-12 col-lg-6 col-xl-5">
						<div class="_villas-365-property-header-inner">
							<div class="_villas-365-property-header-inner-background">
								<div id="_villas-365-property-header-close-button"><i class="fas fa-times"></i></div>
								<div class="row">
									<div class="col">
										<h1 class="_villas-365-property-name"><?php echo esc_html($property->name); ?></h1>
									</div>
								</div>
								
								<?php if (!is_null($property->brief) && (trim($property->brief) !== "")) : ?>
								<div class="row">
									<div class="col">
										<div class="_villas-365-property-summary">
										<?php echo esc_html(Helpers365::StrLimit(Helpers365::Get365TranslationValue($property, ["brief"], ["languages", "brief"]), 300)); ?>
										</div>
									</div>
								</div>
								<?php endif; ?>

								<div class="row mt-3">
									<div class="col">
										<a href="<?php echo esc_html($bookingPageUrl); ?>" class="_villas-365-property-button btn btn-primary"><?php __v3te("Book Now"); ?></a>
									</div>
								</div>
							</div>
						</div>
					</div>
				</div>
			</div>
		</div>
		<?php endif; ?>
	</div>
	<?php else : ?>
	<div id="property-image" class="margin-bottom-gutter" style="background-image:url('<?php echo esc_html($property->image_path) ?>');">
		<img src="<?php echo esc_html($property->image_path) ?>" alt="<?php echo (!is_null($property->name) && (trim($property->name) !== "") ? $property->name : ''); ?>" class="img-fluid d-md-none">
		
		<?php if($showIntroBox) : ?>
		<div class="_villas-365-property-header">
			<div class="container">
				<div class="row align-items-center">
					<div class="col-12 col-lg-6 col-xl-4">
						<div class="_villas-365-property-header-inner">
							<div class="_villas-365-property-header-inner-background">
								<div class="row">
									<div class="col">
										<h1 class="_villas-365-property-name"><?php echo esc_html($property->name); ?></h1>
									</div>
								</div>
								
								<?php if (!is_null($property->brief) && (trim($property->brief) !== "")) : ?>
								<div class="row">
									<div class="col">
										<div class="_villas-365-property-summary">
										<?php echo esc_html(Helpers365::StrLimit(Helpers365::Get365TranslationValue($property, ["brief"], ["languages", "brief"]), 300)); ?>
										</div>
									</div>
								</div>
								<?php endif; ?>

								<div class="row mt-3">
									<div class="col">
										<a href="<?php echo esc_html($bookingPageUrl); ?>" class="_villas-365-property-button btn btn-primary"><?php __v3te("Book Now"); ?></a>
									</div>
								</div>
							</div>
						</div>
					</div>
				</div>
			</div>
		</div>
		<?php endif; ?>
	</div>
	<?php endif; ?>
</div>
<?php endif; ?>