<?php

/**
 * Provide a public-facing view for the plugin
 *
 * This file is used to markup the public-facing aspects of the plugin.
 *
 * @link       https://loyaltymatters.co.uk
 * @since      1.0.0
 *
 * @package    Villas_365
 * @subpackage Villas_365/public/partials
 */

wp_enqueue_style('_villas-365-datepicker-styles-custom', plugin_dir_url( __FILE__ ) . "../../assets/css/villas-365-datepicker.css", [], "1.0.0");
wp_enqueue_script('_villas-365-datepicker-scripts', plugin_dir_url( __FILE__ ) . "../../assets/js/villas-365-datepicker.js", ['jquery'], "1.0.0", true);

wp_enqueue_style('_villas-365-fontawesome', plugin_dir_url( __FILE__ ) . "../../assets/css/villas-365-fontawesome.css", [], "5.9.0");
wp_enqueue_style('_villas-365-chosen-styles', plugin_dir_url( __FILE__ ) . "../../assets/libs/chosen/chosen.css", ["_villas-365-fontawesome"], "1.0");
wp_enqueue_style('_villas-365-styles', plugin_dir_url( __FILE__ ) . "../../assets/css/villas-365-styles.css", ["_villas-365-fontawesome", "_villas-365-chosen-styles", "_villas-365-datepicker-styles-custom"], "1.0");
wp_enqueue_style('_villas-365-property-floater', plugin_dir_url( __FILE__ ) . "../../assets/css/villas-365-property-floater.css", ["_villas-365-styles"], "1.0");
wp_enqueue_script('_villas-365-chosen-scripts', plugin_dir_url( __FILE__ ) . '../../assets/libs/chosen/chosen.js', ['jquery'], "1.0", true);
wp_enqueue_script('_villas-365-property-floater', plugin_dir_url( __FILE__ ) . "../../assets/js/villas-365-property-floater.js", ["jquery", "_villas-365-chosen-scripts", "_villas-365-datepicker-scripts"], "1.0.0", true);

wp_localize_script('_villas-365-property-floater', '_villas_365_wp_ajax', [
	'ajax_url' => admin_url('admin-ajax.php'),
	'nonce' => wp_create_nonce('_villas_365_calculate_booking')
]);

wp_add_inline_style('_villas-365-datepicker-styles-custom', Helpers365::GetCalendarColours());

//Get the property details
$property = $property_atts["property"];
$minimumNights = null;
$defaultSettings = null;
$contactPageUrl = get_home_url() . "/contact";
$bookingPageUrl = get_home_url() . "/book-now";
$enquireLabel = __v3t("Inquire");
$nonAvailableDates = [];

if(!is_null($property))
{
	$defaultSettings = API365::GetDefaultSettings();

	if(isset($property_atts) && (count($property_atts) > 0) && array_key_exists("contactPageUrl", $property_atts) && !is_null($property_atts["contactPageUrl"]) && ($property_atts["contactPageUrl"] !== ""))
	{
		$contactPageUrl = $property_atts["contactPageUrl"];
	}

	if(isset($property_atts) && (count($property_atts) > 0) && array_key_exists("bookingPageUrl", $property_atts) && !is_null($property_atts["bookingPageUrl"]) && ($property_atts["bookingPageUrl"] !== ""))
	{
		$bookingPageUrl = $property_atts["bookingPageUrl"];
	}

	if(property_exists($property, "minimumStay") && !is_null($property->minimumStay) && ($property->minimumStay !== ""))
	{
		$minimumNights = $property->minimumStay;
	}

	if(!is_null($defaultSettings) && property_exists($defaultSettings, "use_enquire") && ($defaultSettings->use_enquire == 1))
	{
		$enquireLabel = __v3t("Enquire");
	}

	$nonAvailableDateRanges = API365::GetNonAvailableDates($property->id);

	$nonAvailableDates = Helpers365::MakeNonAvailableDatesList($nonAvailableDateRanges);
	$nonAvailableDatesJS = null;
	if(!is_null($nonAvailableDates) && (count($nonAvailableDates) > 0))
	{
		$nonAvailableDatesJS = 'var _365_nonAvailableDates = ' . json_encode($nonAvailableDates) . ';';
	}

	$nonAvailableDatesDisplay = Helpers365::MakeNonAvailableDatesDisplayList($nonAvailableDateRanges);
	if(!is_null($nonAvailableDatesDisplay) && (count($nonAvailableDatesDisplay) > 0))
	{
		$nonAvailableDatesJS .= 'var _365_nonAvailableDatesDisplay = ' . json_encode($nonAvailableDatesDisplay) . ';';
	}

	if(!is_null($nonAvailableDatesJS))
	{
		wp_add_inline_script('_villas-365-datepicker-scripts', $nonAvailableDatesJS, "before");
	}
}

if(!is_null($property)) :
?>
<div class="_villas-365-bootstrap _villas-365-property-container">
	<div id="_villas-365-property-floater-anchor"></div>
	<div id="_villas-365-property-floater" class="d-none d-lg-block" data-property-id="<?php echo esc_html($property->id) ?>">
		<div class="container">
			<div class="row justify-content-end">
				<div class="col-12 col-lg-4">
					<div class="_villas-365-property-floater-content">
						<div class="_villas-365-property-floater-header">
							<div class="row align-items-center">
								<div class="col-12 col-lg-6">
									<?php __v3te("We're here to help:"); ?>
								</div>
								<div class="col-12 col-lg-6">
									<a href="<?php echo esc_html($contactPageUrl); ?>" class="_villas-365-property-button _villas-365-property-button-alt btn btn-block btn-primary"><?php __v3te("Contact Us"); ?></a>
								</div>
							</div>
						</div>
						<div class="_villas-365-property-floater-body">
							<div class="row">
								<?php
								$defaultPerNight = __v3t("From") . " " . esc_html($property->rateValue) . "/" . __v3t(($property->rateLabel == "day" ? "night" : $property->rateLabel));
								$rateLabel = __v3t(($property->rateLabel == "day" ? "night" : $property->rateLabel));
								$rateLabelPlural = __v3tn($rateLabel, 2);
								?>
								<div id="_villas-365-property-floater-price-per-night"
									class="col-12"
									data-default-per-night="<?php echo $defaultPerNight ?>"
									data-rate-label="<?php echo esc_html($rateLabel) ?>"
									data-rate-label-plural="<?php echo esc_html($rateLabelPlural) ?>">
									<?php echo $defaultPerNight ?>
								</div>
							</div>
							<div class="row">
								<div class="col-12">
									<hr>
								</div>
							</div>
							<div class="row">
								<div class="col-12">
									<label><?php __v3te("Dates"); ?></label>
								</div>
							</div>
							<div class="row mb-3 _villas-365-date-range-container">
								<div class="col-6 pr-0">
									<div class="_villas-365-date-container">
										<label class="d-none" for="checkin"><?php __v3te("Arrival Date"); ?></label>
										<input type="text" class="form-control _villas-365-checkin _villas-365-date-control _villas-365-date-control-start" value="" placeholder="<?php __v3te("Check-in"); ?>" data-start-field-id="_villas-365-checkin" data-end-field-id="_villas-365-checkout">
									</div>
								</div>
								<div class="col-6 pl-0">
									<div class="_villas-365-date-container">
										<label class="d-none" for="checkout"><?php __v3te("Departure Date"); ?></label>
										<input type="text" class="form-control _villas-365-checkout _villas-365-date-control _villas-365-date-control-end" value="" placeholder="<?php __v3te("Check-out"); ?>">
									</div>
								</div>
							</div>
							<div class="row mb-3">
								<div class="col-12">
									<label for="adults"><?php __v3te("Adults"); ?></label>
									<select id="_villas-365-adults" name="adults" class="form-control search-text chosen-select chosen-select-single" placeholder="<?php __v3te("Adults"); ?>" data-placeholder="<?php __v3te("Adults"); ?>">
										<option value=""></option>
										<?php
										for($counter = 1; $counter <= 20; $counter++) :
										?>
										<option value="<?php echo $counter; ?>"><?php echo $counter; ?></option>
										<?php endfor; ?>
									</select>
								</div>
							</div>
							<div class="row mb-3">
								<div class="col-12">
									<label for="children"><?php __v3te("Children"); ?></label>
									<select id="_villas-365-children" name="children" class="form-control search-text chosen-select chosen-select-single" placeholder="<?php __v3te("Children"); ?>" data-placeholder="<?php __v3te("Children"); ?>">
										<option value=""></option>
										<?php
										for($counter = 1; $counter <= 20; $counter++) :
										?>
										<option value="<?php echo $counter; ?>"><?php echo $counter; ?></option>
										<?php endfor; ?>
									</select>
								</div>
							</div>
							<div id="_villas-365-property-floater-total-row" class="row mb-3">
								<div id="_villas-365-property-floater-total-label" class="col-auto d-none"><?php __v3te("Total"); ?></div>
								<div id="_villas-365-property-floater-total" class="col"></div>
							</div>
							<div id="_villas-365-property-floater-price-details-row" class="row mb-3 d-none">
								<div class="col">
									<div class="row">
										<div class="col">
											<div id="_villas-365-property-floater-price-details-button" class="collapsed" data-rotate-class="rotate-180r">
												<span class="hide-on-show"><?php __v3te("Price details"); ?></span><span class="show-on-show"><?php __v3te("Hide details"); ?></span>
												<span class="button-icon"><i class="fas fa-chevron-down rotate"></i></span>
											</div>
										</div>
									</div>

									<div class="_villas-365-property-floater-price-details-container" style="display:none;" data-collapsed="true">
										<div class="row mb-2">
											<div id="_villas-365-property-floater-price-details-label-per-night" class="col _villas-365-property-floater-price-details-label col-auto"><?php __v3te("Rent"); ?></div>
											<div id="_villas-365-property-floater-price-details-per-night" class="_villas-365-property-floater-price-details col"></div>
										</div>
										<div class="row mb-2">
											<div id="_villas-365-property-floater-price-details-label-fees" class="col _villas-365-property-floater-price-details-label col-auto"><?php __v3te("Service fees"); ?></div>
											<div id="_villas-365-property-floater-price-details-fees" class="_villas-365-property-floater-price-details col"></div>
										</div>
										<div class="row">
											<div id="_villas-365-property-floater-price-details-label-tax" class="col _villas-365-property-floater-price-details-label col-auto"><?php __v3te("Tax"); ?></div>
											<div id="_villas-365-property-floater-price-details-tax" class="_villas-365-property-floater-price-details col"></div>
										</div>
									</div>
								</div>
							</div>
							<div class="row">
								<div class="col-6 pr-1">
									<a href="<?php echo esc_html($bookingPageUrl); ?>" class="_villas-365-property-floater-book-now-button _villas-365-property-button _villas-365-property-button-inverted btn btn-block btn-primary"><?php __v3te($enquireLabel); ?></a>
								</div>
								<div class="col-6 pl-1">
									<a href="<?php echo esc_html($bookingPageUrl); ?>" class="_villas-365-property-floater-book-now-button _villas-365-property-button btn btn-block btn-primary"><?php __v3te("Book Now"); ?></a>
								</div>
							</div>
							<?php if(!is_null($minimumNights)) : ?>
							<div id="_villas-365-property-floater-minimum-nights-container" class="row mt-3">
								<div class="col-12">
									<?php __v3te("There is a %NUMBER night minimum.", ["%NUMBER" => '<span id="_villas-365-property-floater-minimum-nights" data-default-minimum-nights="' . esc_html($minimumNights) . '">' . esc_html($minimumNights) . '</span>']); ?><span id="_villas-365-property-floater-minimum-nights-dates-text" style="display:none;">&nbsp;<?php __v3te("Please %ENQUIRELABEL or extend your stay.", ["%ENQUIRELABEL" => __v3te(strtolower($enquireLabel))]); ?></span>
								</div>
							</div>
							<?php endif; ?>
							<div id="_datetime-hidden-fields">
								<input id="_villas-365-checkin" type='hidden' name='checkin' value="">
								<input id="_villas-365-checkout" type='hidden' name='checkout' value="">
							</div>
						</div>
					</div>
				</div>
			</div>
		</div>
	</div>
</div>
<?php endif; ?>