<?php

/**
 * Provide a public-facing view for the plugin
 *
 * This file is used to markup the public-facing aspects of the plugin.
 *
 * @link       https://loyaltymatters.co.uk
 * @since      1.0.0
 *
 * @package    Villas_365
 * @subpackage Villas_365/public/partials
 */

wp_enqueue_style('_villas-365-styles', plugin_dir_url( __FILE__ ) . "../../assets/css/villas-365-styles.css", [], "1.0");
wp_enqueue_style('_villas-365-property-rates-styles', plugin_dir_url( __FILE__ ) . "../../assets/css/villas-365-property-rates.css", ["_villas-365-styles"], "1.0");

//Get the property
$property = $property_atts["property"];

$showRateDates = false;
if(array_key_exists("showratedates", $property_atts) &&
	!is_null($property_atts["showratedates"]) &
	((!is_bool($property_atts["showratedates"]) && $property_atts["showratedates"] == "true") || (is_bool($property_atts["showratedates"]) && $property_atts["showratedates"])))
{
	$showRateDates = true;
}

$showRateName = true;
if(array_key_exists("showratename", $property_atts) &&
	!is_null($property_atts["showratename"]) &
	((!is_bool($property_atts["showratename"]) && $property_atts["showratename"] == "false") || (is_bool($property_atts["showratename"]) && !$property_atts["showratename"])))
{
	$showRateName = false;
}

if(!is_null($property)) :
?>
<div class="_villas-365-bootstrap _villas-365-property-rates-table">
	<?php
	$ratesTableData = API365::GetRateTable($property->id);

	//If we have at least one daily rate and one weekly rate we need to show the columns.
	$hasDaily = false;
	$hasWeekly = false;
	foreach($ratesTableData->seasons as $ratesTableItem)
	{
		if(property_exists($ratesTableItem, "nightly"))
		{
			$hasDaily = true;
		}

		if(property_exists($ratesTableItem, "weekly"))
		{
			$hasWeekly = true;
		}

		if($hasDaily && $hasWeekly)
		{
			break;
		}
	}

	if(!is_null($ratesTableData)) : ?>
	<div class="row _villas-365-property-rates-table-header d-none d-lg-flex">
		<?php if($showRateName) : ?>
		<div class="col-12 col-lg"><?php __v3te("Rates"); ?></div>
		<?php endif; ?>

		<?php if($showRateDates) : ?>
		<div class="col-12 <?php echo (!$showRateName ? 'col-lg' : 'col-lg-3'); ?> text-center"><?php __v3te("From"); ?></div>
		<div class="col-12 <?php echo (!$showRateName ? 'col-lg' : 'col-lg-3'); ?> text-center"><?php __v3te("To"); ?></div>
		<?php endif; ?>

		<?php if($hasDaily) : ?>
		<div class="col-12 <?php echo (!$showRateName ? 'col-lg' : 'col-lg-2'); ?> text-center"><?php __v3te("Daily"); ?></div>
		<?php endif; ?>

		<?php if($hasWeekly) : ?>
		<div class="col-12 <?php echo (!$showRateName ? 'col-lg' : 'col-lg-2'); ?> text-center"><?php __v3te("Weekly"); ?></div>
		<?php endif; ?>
	</div>

	<?php
	$ratesCounter = 0;
	foreach($ratesTableData->seasons as $ratesTableItem) :
	?>
	<div class="row _villas-365-property-rates-table-item">
		<div class="col">
			<div class="_villas-365-property-rates-table-item-inner<?php echo ($ratesCounter % 2 ? ' _villas-365-property-rates-table-item-inner-alt' : ''); ?>">
				<div class="row align-items-center">
					<?php if($showRateName) : ?>
					<div class="col-12 col-lg"><?php echo esc_html($ratesTableItem->seasonName); ?></div>
					<?php endif; ?>

					<?php if($showRateDates) : ?>
					<div class="col-12 <?php echo (!$showRateName ? 'col-lg' : 'col-lg-3'); ?> text-lg-center">
						<?php if(property_exists($ratesTableItem, "startDate")) : ?>
							<strong class="d-inline d-lg-none"><?php __v3te("From"); ?>: </strong><?php echo esc_html(date_create_from_format("Y-m-d", $ratesTableItem->startDate)->format("d M Y")); ?>
						<?php endif; ?>
					</div>
					<div class="col-12 <?php echo (!$showRateName ? 'col-lg' : 'col-lg-3'); ?> text-lg-center">
						<?php if(property_exists($ratesTableItem, "endDate")) : ?>
							<strong class="d-inline d-lg-none"><?php __v3te("To"); ?>: </strong><?php echo esc_html(date_create_from_format("Y-m-d", $ratesTableItem->endDate)->format("d M Y")); ?>
						<?php endif; ?>
					</div>
					<?php endif; ?>
					
					<?php if($hasDaily) : ?>
					<div class="col-12 <?php echo (!$showRateName ? 'col-lg' : 'col-lg-2'); ?> text-lg-center">
						<?php if(property_exists($ratesTableItem, "nightly")) : ?>
							<strong class="d-inline d-lg-none"><?php __v3te("Daily"); ?>: </strong><?php echo esc_html($ratesTableData->currencySymbol) . esc_html($ratesTableItem->nightly); ?>
						<?php else: ?>
							<?php __v3te("N/A"); ?>
						<?php endif; ?>
					</div>
					<?php endif; ?>

					<?php if($hasWeekly) : ?>
					<div class="col-12 <?php echo (!$showRateName ? 'col-lg' : 'col-lg-2'); ?> text-lg-center">
						<?php if(property_exists($ratesTableItem, "weekly")) : ?>
							<strong class="d-inline d-lg-none"><?php __v3te("Weekly"); ?>: </strong><?php echo esc_html($ratesTableData->currencySymbol) . esc_html($ratesTableItem->weekly); ?>
						<?php else: ?>
							<?php __v3te("N/A"); ?>
						<?php endif; ?>
					</div>
					<?php endif; ?>
				</div>
			</div>
		</div>
	</div>
	<?php
	$ratesCounter++;
	endforeach;
	else : ?>
	<div class="row _villas-365-property-rates-table-item">
		<div class="col">
			<?php __v3te("There was an error getting the rate information. Please check your API keys and if the issue is still present contact 365villas."); ?>
		</div>
	</div>
	<?php endif;?>
</div>
<?php endif; ?>