<?php

/**
 * Provide a public-facing view for the plugin
 *
 * This file is used to markup the public-facing aspects of the plugin.
 *
 * @link       http://example.com
 * @since      1.0.0
 *
 * @package    Villas_365
 * @subpackage Villas_365/public/partials
 */

wp_enqueue_style('_villas-365-fontawesome', plugin_dir_url( __FILE__ ) . "../assets/css/villas-365-fontawesome.css", [], "5.9.0");
wp_enqueue_style('_villas-365-styles', plugin_dir_url( __FILE__ ) . "../assets/css/villas-365-styles.css", ["_villas-365-fontawesome"], "1.0");
wp_enqueue_style('_villas-365-featured-properties-styles', plugin_dir_url( __FILE__ ) . "../../assets/css/villas-365-featured-properties.css", ["_villas-365-styles"], "1.0");

$villas365CSSOverrides = Helpers365::GenerateCSSOverrides();
wp_add_inline_style('_villas-365-featured-properties', $villas365CSSOverrides);

$propertiesPerRow = 3;
if(isset($propertiesFeatured_atts) && (count($propertiesFeatured_atts) > 0) && array_key_exists("perrow", $propertiesFeatured_atts) && is_numeric($propertiesFeatured_atts["perrow"]))
{
	$propertiesPerRow = $propertiesFeatured_atts["perrow"];
}

$propertiesLimit = 3;
if(isset($propertiesFeatured_atts) && (count($propertiesFeatured_atts) > 0) && array_key_exists("limit", $propertiesFeatured_atts) && is_numeric($propertiesFeatured_atts["limit"]))
{
	$propertiesLimit = $propertiesFeatured_atts["limit"];
}

$propertyPageURL = null;
if(isset($propertiesFeatured_atts) && (count($propertiesFeatured_atts) > 0) && array_key_exists("propertypageid", $propertiesFeatured_atts) && is_numeric($propertiesFeatured_atts["propertypageid"]))
{
	$propertyPageURL = Helpers365::GetPropertyPageURL($propertiesFeatured_atts["propertypageid"]);
}

if(!isset($villas365PropertiesOpenInNewTabsHTML) || is_null($villas365PropertiesOpenInNewTabsHTML))
{
	$villas365PropertiesOpenInNewTabsHTML = Helpers365::GetOpenPropertiesInNewTabsHTML();
}

//Get the property details
$properties = API365::SearchProperties([
	"isfeatured" => 1,
	"limit" => $propertiesLimit
]);
if(!is_null($properties) && ($properties["count"] > 0)) :
?>
<div class="_villas-365-bootstrap _villas-365-properties _villas-365-properties-featured">
	<div class="container">
		<?php foreach(array_chunk($properties["properties"], $propertiesPerRow) as $featuredPropertiesChunk): ?>
		<div class="row">
			<?php foreach($featuredPropertiesChunk as $featuredProperty): ?>
			<div class="_villas-365-property col-md margin-bottom-gutter">
				<?php
				$featuredPropertyTemplate = Helpers365::LocateTemplateFile("villas-365-properties-featured-item-grid.php");
				if($featuredPropertyTemplate === FALSE)
				{
					echo "<pre>Featured property template could not be found.</pre>";
				}
				else
				{
					include $featuredPropertyTemplate;
				}
				?>
			</div>
			<?php endforeach; ?>
		</div>
		<?php endforeach; ?>
	</div>
</div>
<?php endif; ?>