<?php

/**
 * Provide a public-facing view for the plugin
 *
 * This file is used to markup the public-facing aspects of the plugin.
 *
 * @link       https://loyaltymatters.co.uk
 * @since      1.0.0
 *
 * @package    Villas_365
 * @subpackage Villas_365/public/partials
 */

wp_enqueue_style('_villas-365-styles', plugin_dir_url( __FILE__ ) . "../assets/css/villas-365-styles.css", [], "1.0");
wp_enqueue_style('_villas-365-properties-list-styles', plugin_dir_url( __FILE__ ) . "../assets/css/villas-365-properties-list.css", [], "1.0");
wp_enqueue_script('_villas-365-properties-list-scripts', plugin_dir_url( __FILE__ ) . '../assets/js/villas-365-properties-list.js', ['jquery'], "1.0", true);

$villas365CSSOverrides = Helpers365::GenerateCSSOverrides();
wp_add_inline_style('_villas-365-styles', $villas365CSSOverrides);

$propertiesPerRow = 3;
if(isset($propertiesList_atts) && (count($propertiesList_atts) > 0) && array_key_exists("perrow", $propertiesList_atts) && is_numeric($propertiesList_atts["perrow"]))
{
	$propertiesPerRow = $propertiesList_atts["perrow"];
}

$propertiesPerPage = 10;
if(isset($propertiesList_atts) && (count($propertiesList_atts) > 0) && array_key_exists("perpage", $propertiesList_atts) && is_numeric($propertiesList_atts["perpage"]))
{
	$propertiesPerPage = $propertiesList_atts["perpage"];
}

$propertyPageURL = null;
if(isset($propertiesList_atts) && (count($propertiesList_atts) > 0) && array_key_exists("propertypageid", $propertiesList_atts) && is_numeric($propertiesList_atts["propertypageid"]))
{
	$propertyPageURL = Helpers365::GetPropertyPageURL($propertiesList_atts["propertypageid"]);
}

$propertiesListView = "list";
if(isset($propertiesList_atts) && (count($propertiesList_atts) > 0) && array_key_exists("view", $propertiesList_atts))
{
	$propertiesListView = $propertiesList_atts["view"];
}

if(!isset($villas365PropertiesOpenInNewTabsHTML) || is_null($villas365PropertiesOpenInNewTabsHTML))
{
	$villas365PropertiesOpenInNewTabsHTML = Helpers365::GetOpenPropertiesInNewTabsHTML();
}

//Get the properties
$properties = null;
$searchParameters = null;
if(isset($_GET) && is_array($_GET) && ((array_key_exists("ppage", $_GET) && (count($_GET) > 0)) || (!array_key_exists("ppage", $_GET) && (count($_GET) > 0))))
{
	$searchParameters = $_GET;
}

$properties = API365::SearchProperties([
	"limit" => $propertiesPerPage
], $searchParameters);

$page = 1;
if(isset($_GET) && is_array($_GET) && (count($_GET) > 0) && array_key_exists("ppage", $_GET) && is_numeric($_GET["ppage"]))
{
	$page = $_GET["ppage"];
}

$searchParametersSearchResults = API365::GetSearchParameters();
if(isset($_GET) && is_array($_GET))
{
	$searchParametersSearchResults = API365::GetSearchParameters($_GET);
}

$propertiesListView = $searchParametersSearchResults["view"];

$searchPageURLSearchResults = null;
if(isset($search_atts) && (count($search_atts) > 0) && array_key_exists("searchpageid", $search_atts) && is_numeric($search_atts["searchpageid"]))
{
	$searchPageURLSearchResults = get_page_link($search_atts["searchpageid"]);
}

if($page > $properties["totalPages"]) :
?>

<div class="_villas-365-bootstrap _villas-365-properties">
	<div class="container">
		<div class="row">
			<div class="col">
				<?php esc_html_e("No properties found for your search. Try changing dates or filters to expand your search.", "villas-365-website-td"); ?>
			</div>
		</div>
	</div>
</div>

<?php Helpers365::Abort404(); ?>

<?php elseif(!is_null($properties) && ($properties["count"] > 0)) :
	$viewClass = '_villas-365-properties-grid';
	if($propertiesListView === 'list')
	{
		$viewClass = '_villas-365-properties-list';
	}
	elseif($propertiesListView === 'map')
	{
		$viewClass = '_villas-365-properties-map';
	}
?>
<div class="_villas-365-bootstrap _villas-365-properties <?php echo $viewClass; ?>">
	<div class="_villas-365-properties-header">
		<?php
		$propertiesListHeaderTemplate = Helpers365::LocateTemplateFile("villas-365-properties-list-header.php");
		if($propertiesListHeaderTemplate === FALSE)
		{
			echo "<pre>List header template could not be found.</pre>";
		}
		else
		{
			include $propertiesListHeaderTemplate;
		}
		?>
	</div>

	<div class="container mt-4">
		<?php
		$propertiesArray = (array)$properties->properties;
		?>

		<?php if($propertiesListView === "grid") : ?>
			<?php $propertiesListItemTemplate = Helpers365::LocateTemplateFile("villas-365-properties-list-item-grid.php"); ?>
			<?php foreach(array_chunk($properties["properties"], $propertiesPerRow) as $propertiesChunk): ?>
			<div class="row">
				<?php
				//Add some empty properties so the columns on the page add up correctly and are the correct width.
				while(count($propertiesChunk) < $propertiesPerRow)
				{
					$propertiesChunk[] = null;
				}
				?>
				<?php foreach($propertiesChunk as $property): ?>
				<div class="<?php echo (!is_null($property) ? '_villas-365-property' : ''); ?> col-md mb-3">
					<?php if(!is_null($property)) : ?>
						<?php
						if($propertiesListItemTemplate === FALSE)
						{
							echo "<pre>Template could not be found.</pre>";
						}
						else
						{
							include $propertiesListItemTemplate;
						}
						?>
					<?php endif; ?>
				</div>
				<?php endforeach; ?>
			</div>
			<?php endforeach; ?>
		<?php elseif($propertiesListView === "map") : ?>
			<?php
			$googleMapsAPIKey = FALSE;
			if(class_exists('Helpers365'))
			{
				$googleMapsAPIKey = Helpers365::GetOption("_google_maps_api_key");
			}

			if($googleMapsAPIKey !== FALSE) :
				wp_enqueue_script('_villas-365-googlemaps', "https://maps.googleapis.com/maps/api/js?v=3&key=" . $googleMapsAPIKey, [], "3.0", true);
				wp_enqueue_script('_villas-365-map-helpers', plugin_dir_url( __FILE__ ) . "../assets/js/villas-365-map-helpers.js", ["jquery", "_villas-365-googlemaps"], "1.0", true);
				wp_enqueue_script('_villas-365-properties-map', plugin_dir_url( __FILE__ ) . "../assets/js/villas-365-properties-map.js", ["jquery", "_villas-365-googlemaps", "_villas-365-map-helpers"], "1.0", true);
				
				$propertiesListItemTemplate = Helpers365::LocateTemplateFile("villas-365-properties-list-map.php");
				if($propertiesListItemTemplate === FALSE)
				{
					echo "<pre>Template could not be found.</pre>";
				}
				else
				{
					include $propertiesListItemTemplate;
				}
			else :
			?>
			<div class="_villas-365-bootstrap _villas-365-error-container">
				<div class="container mt-gutter mb-gutter">
					<div class="row">
						<div class="col-12">
							Google Maps API key not set in 365villas settings.<br>
							Please add a valid Google Maps API key in the WordPress 365villas plugin settings.
						</div>
					</div>
				</div>
			</div>
			<?php endif; ?>
		<?php else : ?>
			<?php $propertiesListItemTemplate = Helpers365::LocateTemplateFile("villas-365-properties-list-item-list.php"); ?>
			<?php foreach($properties["properties"] as $property): ?>
			<?php if(!is_null($property)) : ?>
			<div class="row">
				<div class="col mb-4">
					<div class="_villas-365-property">
						<?php
						if($propertiesListItemTemplate === FALSE)
						{
							echo "<pre>Template could not be found.</pre>";
						}
						else
						{
							include $propertiesListItemTemplate;
						}
						?>
					</div>
				</div>
			</div>
			<?php endif; ?>
			<?php endforeach; ?>
		<?php endif; ?>

		<?php if($properties["totalPages"] > 1) :
			$currentPageURLBase = null;
			$currentPageURLData = null;
			$currentPageNumber = 1;
			$currentPage = get_post();
			if(!is_null($currentPage))
			{
				$currentPageURLBase = get_page_link($currentPage->id);

				if(isset($_GET) && is_array($_GET) && (count($_GET) > 0))
				{
					$currentPageURLData = $_GET;
					if(array_key_exists("ppage", $currentPageURLData))
					{
						$currentPageNumber = $currentPageURLData["ppage"];
						unset($currentPageURLData["ppage"]);
					}
				}
			}

			if(!is_null($currentPageURLBase)) :
		?>
			<?php
			$propertiesListPaginatorTemplate = Helpers365::LocateTemplateFile("villas-365-properties-list-paginator.php");
			if($propertiesListPaginatorTemplate === FALSE)
			{
				echo "<pre>Template could not be found.</pre>";
			}
			else
			{
				include $propertiesListPaginatorTemplate;
			}
			?>
		<?php
			endif;
		endif;
		?>
	</div>
</div>
<?php else : ?>
<div class="_villas-365-bootstrap _villas-365-properties">
	<div class="container">
		<div class="row">
			<div class="col">
				<?php esc_html_e("No properties found.", "villas-365-website-td"); ?>
			</div>
		</div>
	</div>
</div>
<?php endif; ?>