<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://www.365villas.com
 * @since             1.2.7
 * @package           Villas_365
 *
 * @wordpress-plugin
 * Plugin Name:       365villas
 * Plugin URI:        https://www.365villas.com
 * Description:       Adds various functions related to 365villas.
 * Version:           1.2.7
 * Author:            LoyaltyMATTERS
 * Author URI:        https://loyaltymatters.co.uk
 * License:           Copyright (C) 2018 365villas.
 * Text Domain:       villas-365
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'VILLAS_365_VERSION', '1.2.7' );

define( 'VILLAS_365_PLUGIN_PATH', plugin_dir_path( __FILE__ ) );

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-villas-365-activator.php
 */
function activate_villas_365() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-villas-365-activator.php';
	Villas_365_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-villas-365-deactivator.php
 */
function deactivate_villas_365() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-villas-365-deactivator.php';
	Villas_365_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_villas_365' );
register_deactivation_hook( __FILE__, 'deactivate_villas_365' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-villas-365.php';

/**
 * 365villas Classes
 */
require plugin_dir_path( __FILE__ ) . 'includes/API365/API365.php';
require plugin_dir_path( __FILE__ ) . 'includes/API365/Helpers365.php';

//Add the update checker.
require plugin_dir_path( __FILE__ ) . 'includes/plugin-update-checker/plugin-update-checker.php';
$myUpdateChecker = Puc_v4_Factory::buildUpdateChecker(
	'https://gitlab.com/365villas/villas-365/',
	__FILE__,
	'villas-365'
);
$myUpdateChecker->setAuthentication('Bn1kB3kUPfzKmS7XJMCg');

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_villas_365() {

	$plugin = new Villas_365();
	$plugin->run();

}
run_villas_365();
